==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SuffixDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputGroupItemDescriptionMetadata } from "./InputGroupItemDescriptionMetadata";
import { SuffixDescription } from "./SuffixDescription";
/**
 * @hidden
 */
var SuffixDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SuffixDescriptionMetadata, _super);
    function SuffixDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SuffixDescriptionMetadata.b = function (a) {
        if (SuffixDescriptionMetadata.a == null) {
            SuffixDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SuffixDescriptionMetadata.c(SuffixDescriptionMetadata.a);
        }
        if (a.j(SuffixDescriptionMetadata.a)) {
            return;
        }
        a.y(SuffixDescriptionMetadata.a);
    };
    SuffixDescriptionMetadata.c = function (a) {
        InputGroupItemDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:XSuffix");
        a.item("Id", "String");
        a.item("AriaLabel", "String");
        a.item("IsHover", "Boolean");
        a.item("Disabled", "(w:IsDisabled,xam:IsDisabled,wf:IsDisabled)Boolean");
    };
    SuffixDescriptionMetadata.d = function (a) {
        SuffixDescriptionMetadata.b(a);
        a.aa("Suffix", function () { return new SuffixDescription(); });
        a.z("Suffix", SuffixDescriptionMetadata.a);
    };
    SuffixDescriptionMetadata.$t = markType(SuffixDescriptionMetadata, 'SuffixDescriptionMetadata');
    SuffixDescriptionMetadata.a = null;
    return SuffixDescriptionMetadata;
}(Base));
export { SuffixDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SuffixDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { InputGroupItemDescriptionMetadata } from "./InputGroupItemDescriptionMetadata";
import { SuffixDescription } from "./SuffixDescription";
/**
 * @hidden
 */
var SuffixDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SuffixDescriptionMetadata, _super);
    function SuffixDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SuffixDescriptionMetadata.b = function (a) {
        if (SuffixDescriptionMetadata.a == null) {
            SuffixDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SuffixDescriptionMetadata.c(SuffixDescriptionMetadata.a);
        }
        if (a.k(SuffixDescriptionMetadata.a)) {
            return;
        }
        a.aa(SuffixDescriptionMetadata.a);
    };
    SuffixDescriptionMetadata.c = function (a) {
        InputGroupItemDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:XSuffix");
        a.item("Id", "String");
        a.item("AriaLabel", "String");
        a.item("IsHover", "Boolean");
        a.item("Disabled", "(w:IsDisabled,xam:IsDisabled,wf:IsDisabled)Boolean");
    };
    SuffixDescriptionMetadata.d = function (a) {
        SuffixDescriptionMetadata.b(a);
        a.ac("Suffix", function () { return new SuffixDescription(); });
        a.ab("Suffix", SuffixDescriptionMetadata.a);
    };
    SuffixDescriptionMetadata.$t = markType(SuffixDescriptionMetadata, 'SuffixDescriptionMetadata');
    SuffixDescriptionMetadata.a = null;
    return SuffixDescriptionMetadata;
}(Base));
export { SuffixDescriptionMetadata };
